# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/util/lock/node_state.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/models/util/lock/node_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.models.util import endpoint_pb2 as fintekkers_dot_models_dot_util_dot_endpoint__pb2
from fintekkers.models.util.lock import node_partition_pb2 as fintekkers_dot_models_dot_util_dot_lock_dot_node__partition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,fintekkers/models/util/lock/node_state.proto\x12\x1b\x66intekkers.models.util.lock\x1a,fintekkers/models/util/local_timestamp.proto\x1a%fintekkers/models/util/endpoint.proto\x1a\x30\x66intekkers/models/util/lock/node_partition.proto\"\xfa\x01\n\tNodeState\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12=\n\tpartition\x18\x05 \x01(\x0b\x32*.fintekkers.models.util.lock.NodePartition\x12\x33\n\tend_point\x18\x06 \x01(\x0b\x32 .fintekkers.models.util.Endpoint\x12>\n\tlast_seen\x18\x07 \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProto\x12\x12\n\nis_expired\x18\x08 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.util.lock.node_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NODESTATE']._serialized_start=213
  _globals['_NODESTATE']._serialized_end=463
# @@protoc_insertion_point(module_scope)
