# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/util/errors/summary.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/requests/util/errors/summary.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.util.errors import error_pb2 as fintekkers_dot_requests_dot_util_dot_errors_dot_error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-fintekkers/requests/util/errors/summary.proto\x12\x1f\x66intekkers.requests.util.errors\x1a+fintekkers/requests/util/errors/error.proto\"\x8c\x01\n\x0cSummaryProto\x12;\n\x06\x65rrors\x18\x01 \x03(\x0b\x32+.fintekkers.requests.util.errors.ErrorProto\x12?\n\x08warnings\x18\x02 \x03(\x0b\x32-.fintekkers.requests.util.errors.WarningProtob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.util.errors.summary_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SUMMARYPROTO']._serialized_start=128
  _globals['_SUMMARYPROTO']._serialized_end=268
# @@protoc_insertion_point(module_scope)
