# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/position/field.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/models/position/field.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&fintekkers/models/position/field.proto\x12\x1a\x66intekkers.models.position*\xa8\x04\n\nFieldProto\x12\x11\n\rUNKNOWN_FIELD\x10\x00\x12\x06\n\x02ID\x10\x01\x12\t\n\x05\x41S_OF\x10\x02\x12\x12\n\x0e\x45\x46\x46\x45\x43TIVE_DATE\x10\n\x12\x0c\n\x08STRATEGY\x10\x0b\x12\x0c\n\x08SECURITY\x10\x0c\x12\x18\n\x14SECURITY_DESCRIPTION\x10=\x12\x18\n\x14SECURITY_ISSUER_NAME\x10>\x12\x18\n\x14\x43\x41SH_IMPACT_SECURITY\x10\r\x12\x0f\n\x0b\x41SSET_CLASS\x10\x32\x12\x11\n\rPRODUCT_CLASS\x10\x33\x12\x10\n\x0cPRODUCT_TYPE\x10\x34\x12\x0f\n\x0bSECURITY_ID\x10\x35\x12\x0e\n\nIDENTIFIER\x10\x36\x12\t\n\x05TENOR\x10\x37\x12\x0e\n\nISSUE_DATE\x10:\x12\x11\n\rMATURITY_DATE\x10\x38\x12\x12\n\x0e\x41\x44JUSTED_TENOR\x10\x39\x12\r\n\tPORTFOLIO\x10\x0e\x12\x10\n\x0cPORTFOLIO_ID\x10\x0f\x12\x12\n\x0ePORTFOLIO_NAME\x10<\x12\t\n\x05PRICE\x10\x10\x12\x0c\n\x08PRICE_ID\x10\x11\x12\x10\n\x0cIS_CANCELLED\x10\x12\x12\x13\n\x0fPOSITION_STATUS\x10\x13\x12\x0e\n\nTRADE_DATE\x10\x1e\x12\x13\n\x0fSETTLEMENT_DATE\x10\x1f\x12\x14\n\x10TRANSACTION_TYPE\x10 \x12\x15\n\x11TAX_LOT_OPEN_DATE\x10(\x12\x16\n\x12TAX_LOT_CLOSE_DATE\x10)B\x0f\x42\x0b\x46ieldProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.position.field_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\013FieldProtosP\001'
  _globals['_FIELDPROTO']._serialized_start=71
  _globals['_FIELDPROTO']._serialized_end=623
# @@protoc_insertion_point(module_scope)
