from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class FieldProto(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_FIELD: _ClassVar[FieldProto]
    ID: _ClassVar[FieldProto]
    AS_OF: _ClassVar[FieldProto]
    EFFECTIVE_DATE: _ClassVar[FieldProto]
    STRATEGY: _ClassVar[FieldProto]
    SECURITY: _ClassVar[FieldProto]
    SECURITY_DESCRIPTION: _ClassVar[FieldProto]
    SECURITY_ISSUER_NAME: _ClassVar[FieldProto]
    CASH_IMPACT_SECURITY: _ClassVar[FieldProto]
    ASSET_CLASS: _ClassVar[FieldProto]
    PRODUCT_CLASS: _ClassVar[FieldProto]
    PRODUCT_TYPE: _ClassVar[FieldProto]
    SECURITY_ID: _ClassVar[FieldProto]
    IDENTIFIER: _ClassVar[FieldProto]
    TENOR: _ClassVar[FieldProto]
    ISSUE_DATE: _ClassVar[FieldProto]
    MATURITY_DATE: _ClassVar[FieldProto]
    ADJUSTED_TENOR: _ClassVar[FieldProto]
    PORTFOLIO: _ClassVar[FieldProto]
    PORTFOLIO_ID: _ClassVar[FieldProto]
    PORTFOLIO_NAME: _ClassVar[FieldProto]
    PRICE: _ClassVar[FieldProto]
    PRICE_ID: _ClassVar[FieldProto]
    IS_CANCELLED: _ClassVar[FieldProto]
    POSITION_STATUS: _ClassVar[FieldProto]
    TRADE_DATE: _ClassVar[FieldProto]
    SETTLEMENT_DATE: _ClassVar[FieldProto]
    TRANSACTION_TYPE: _ClassVar[FieldProto]
    TAX_LOT_OPEN_DATE: _ClassVar[FieldProto]
    TAX_LOT_CLOSE_DATE: _ClassVar[FieldProto]
UNKNOWN_FIELD: FieldProto
ID: FieldProto
AS_OF: FieldProto
EFFECTIVE_DATE: FieldProto
STRATEGY: FieldProto
SECURITY: FieldProto
SECURITY_DESCRIPTION: FieldProto
SECURITY_ISSUER_NAME: FieldProto
CASH_IMPACT_SECURITY: FieldProto
ASSET_CLASS: FieldProto
PRODUCT_CLASS: FieldProto
PRODUCT_TYPE: FieldProto
SECURITY_ID: FieldProto
IDENTIFIER: FieldProto
TENOR: FieldProto
ISSUE_DATE: FieldProto
MATURITY_DATE: FieldProto
ADJUSTED_TENOR: FieldProto
PORTFOLIO: FieldProto
PORTFOLIO_ID: FieldProto
PORTFOLIO_NAME: FieldProto
PRICE: FieldProto
PRICE_ID: FieldProto
IS_CANCELLED: FieldProto
POSITION_STATUS: FieldProto
TRADE_DATE: FieldProto
SETTLEMENT_DATE: FieldProto
TRANSACTION_TYPE: FieldProto
TAX_LOT_OPEN_DATE: FieldProto
TAX_LOT_CLOSE_DATE: FieldProto
