# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/models/position/position_status.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/models/position/position_status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0fintekkers/models/position/position_status.proto\x12\x1a\x66intekkers.models.position*P\n\x13PositionStatusProto\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cHYPOTHETICAL\x10\x01\x12\x0c\n\x08INTENDED\x10\x02\x12\x0c\n\x08\x45XECUTED\x10\x03\x42\x18\x42\x14PositionStatusProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.models.position.position_status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\024PositionStatusProtosP\001'
  _globals['_POSITIONSTATUSPROTO']._serialized_start=80
  _globals['_POSITIONSTATUSPROTO']._serialized_end=160
# @@protoc_insertion_point(module_scope)
