# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/services/valuation-service/valuation_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/services/valuation-service/valuation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.requests.valuation import valuation_request_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2
from fintekkers.requests.valuation import valuation_response_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=fintekkers/services/valuation-service/valuation_service.proto\x12%fintekkers.services.valuation_service\x1a\x35\x66intekkers/requests/valuation/valuation_request.proto\x1a\x36\x66intekkers/requests/valuation/valuation_response.proto2\x88\x01\n\tValuation\x12{\n\x0cRunValuation\x12\x34.fintekkers.requests.valuation.ValuationRequestProto\x1a\x35.fintekkers.requests.valuation.ValuationResponseProtoB\x06\x88\x01\x01\x90\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.services.valuation_service.valuation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\210\001\001\220\001\001'
  _globals['_VALUATION']._serialized_start=216
  _globals['_VALUATION']._serialized_end=352
_builder.BuildServices(DESCRIPTOR, 'fintekkers.services.valuation_service.valuation_service_pb2', _globals)
# @@protoc_insertion_point(module_scope)
