# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/valuation/valuation_response.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/requests/valuation/valuation_response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.position import position_util_pb2 as fintekkers_dot_models_dot_position_dot_position__util__pb2
from fintekkers.requests.valuation import valuation_request_pb2 as fintekkers_dot_requests_dot_valuation_dot_valuation__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6fintekkers/requests/valuation/valuation_response.proto\x12\x1d\x66intekkers.requests.valuation\x1a.fintekkers/models/position/position_util.proto\x1a\x35\x66intekkers/requests/valuation/valuation_request.proto\"\xd6\x01\n\x16ValuationResponseProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12O\n\x11valuation_request\x18\x14 \x01(\x0b\x32\x34.fintekkers.requests.valuation.ValuationRequestProto\x12\x44\n\x0fmeasure_results\x18\x1e \x03(\x0b\x32+.fintekkers.models.position.MeasureMapEntryB\x1b\x42\x17ValuationResponseProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.valuation.valuation_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\027ValuationResponseProtosP\001'
  _globals['_VALUATIONRESPONSEPROTO']._serialized_start=193
  _globals['_VALUATIONRESPONSEPROTO']._serialized_end=407
# @@protoc_insertion_point(module_scope)
