# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fintekkers/requests/position/query_position_request.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'fintekkers/requests/position/query_position_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.position import field_pb2 as fintekkers_dot_models_dot_position_dot_field__pb2
from fintekkers.models.position import measure_pb2 as fintekkers_dot_models_dot_position_dot_measure__pb2
from fintekkers.models.position import position_pb2 as fintekkers_dot_models_dot_position_dot_position__pb2
from fintekkers.models.position import position_filter_pb2 as fintekkers_dot_models_dot_position_dot_position__filter__pb2
from fintekkers.models.util import local_timestamp_pb2 as fintekkers_dot_models_dot_util_dot_local__timestamp__pb2
from fintekkers.requests.util import operation_pb2 as fintekkers_dot_requests_dot_util_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9fintekkers/requests/position/query_position_request.proto\x12\x1c\x66intekkers.requests.position\x1a&fintekkers/models/position/field.proto\x1a(fintekkers/models/position/measure.proto\x1a)fintekkers/models/position/position.proto\x1a\x30\x66intekkers/models/position/position_filter.proto\x1a,fintekkers/models/util/local_timestamp.proto\x1a(fintekkers/requests/util/operation.proto\"\x93\x04\n\x19QueryPositionRequestProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12K\n\x0eoperation_type\x18\n \x01(\x0e\x32\x33.fintekkers.requests.util.RequestOperationTypeProto\x12\x44\n\rposition_type\x18\x14 \x01(\x0e\x32-.fintekkers.models.position.PositionTypeProto\x12\x44\n\rposition_view\x18\x15 \x01(\x0e\x32-.fintekkers.models.position.PositionViewProto\x12\x36\n\x06\x66ields\x18\x1e \x03(\x0e\x32&.fintekkers.models.position.FieldProto\x12:\n\x08measures\x18\x1f \x03(\x0e\x32(.fintekkers.models.position.MeasureProto\x12\x46\n\rfilter_fields\x18  \x01(\x0b\x32/.fintekkers.models.position.PositionFilterProto\x12:\n\x05\x61s_of\x18! \x01(\x0b\x32+.fintekkers.models.util.LocalTimestampProtoB\x1e\x42\x1aQueryPositionRequestProtosP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.position.query_position_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'B\032QueryPositionRequestProtosP\001'
  _globals['_QUERYPOSITIONREQUESTPROTO']._serialized_start=355
  _globals['_QUERYPOSITIONREQUESTPROTO']._serialized_end=886
# @@protoc_insertion_point(module_scope)
